@@ -15,7 +15,7 @@
 #'  format managed by GDAL (use [s2_translate] to do it);
 #'  their names must be in the sen2r naming convention
 #'  ([safe_shortname]).
-#' @param mask_type (optional) Character vector which determines the type of
+#' @param mask_type Character vector which determines the type of
 #'  mask to be applied. Accepted values are:
 #'  - `"nomask"`: do not mask any pixel;
 #'  - `"nodata"`: mask pixels checked as "No data" or "Saturated or defective"
@@ -55,7 +55,7 @@
 #'  Images with a percentage of masked surface greater than `max_mask`%
 #'  are not processed (the list of expected output files which have not been
 #'  generated is returned as an attribute, named `skipped`).
-#'  Default value is 80.
+#'  Default value is 100 (images are always produced).
 #'  Notice that the percentage is computed on non-NA values (if input images
 #'  had previously been clipped and masked using a polygon, the percentage is
 #'  computed on the surface included in the masking polygons).
@@ -151,10 +151,10 @@
 
 s2_mask <- function(infiles,
                     maskfiles,
-                    mask_type = "cloud_medium_proba",
+                    mask_type,
                     smooth = 0,
                     buffer = 0,
-                    max_mask = 80,
+                    max_mask = 100,
                     outdir = "./masked",
                     tmpdir = NA,
                     rmtmp = TRUE,
