@@ -18,6 +18,10 @@
 #' @param apihub Path of the "apihub.txt" file containing credentials
 #'  of SciHub account.
 #'  If NA (default), the default location inside the package will be used.
+#' @param service Character: it can be `"dhus"` or `"apihub"`, in which cases
+#'  the required service is forced instead that the one present in the URLs
+#'  passed through argument `s2_prodlist`.
+#'  If NA (default), the service present in the URLs is maintained.
 #' @param reorder Logical: If TRUE, and a json file exported by s2_order 
 #'  is passed as argument to the function, try to order again also 
 #'  the `"available"` and `"ordered"` S2 datasets. 
@@ -36,9 +40,9 @@
 #' @author Luigi Ranghetti, phD (2019) \email{luigi@@ranghetti.info}
 #' @author Lorenzo Busetto, phD (2020) \email{lbusett@@gmail.com}
 #' @note License: GPL 3.0
-#' @importFrom httr GET authenticate 
+#' @importFrom httr RETRY authenticate 
 #' @importFrom foreach foreach "%do%"
-#' @importFrom jsonlite fromJSON toJSON
+#' @importFrom jsonlite toJSON
 #' @export
 #'
 #' @examples
@@ -64,6 +68,7 @@ s2_order <- function(
   export_prodlist = TRUE, 
   delay = 0.5, 
   apihub = NA, 
+  service = NA,
   reorder = TRUE
 ) {
   .s2_order(
@@ -71,6 +76,7 @@ s2_order <- function(
     export_prodlist = export_prodlist, 
     delay = delay,
     apihub = apihub,
+    service = service,
     reorder = reorder,
     .s2_availability = NULL
   )
@@ -83,6 +89,7 @@ s2_order <- function(
   export_prodlist = TRUE, 
   delay = 0.5,
   apihub = NA,
+  service = NA,
   reorder = TRUE,
   .s2_availability = NULL,
   .log_path = TRUE # TRUE to log all, FALSE to skip the path of the json
@@ -125,6 +132,15 @@ s2_order <- function(
   s2_prodlist <- as(s2_prodlist, "safelist")
   # TODO add input checks
   
+  # check the used service
+  if (!is.na(service)) {
+    s2_prodlist <- gsub(
+      "^https://scihub.copernicus.eu/((apihub)|(dhus))/odata",
+      paste0("https://scihub.copernicus.eu/",service,"/odata"),
+      s2_prodlist
+    )
+  }
+  
   # read credentials
   creds <- read_scihub_login(apihub)
   
@@ -188,9 +204,10 @@ s2_order <- function(
       Sys.sleep(delay)
     }
     # order products
-    make_order <- httr::GET(
+    make_order <- RETRY(
+      verb = "GET",
       url = as.character(s2_prodlist[i]),
-      config = httr::authenticate(creds[1], creds[2])
+      config = authenticate(creds[1], creds[2])
     )
     
     # check if the order was successful
