@@ -11,7 +11,8 @@ testthat::test_that(
       names(list_param),
       c("preprocess", "s2_levels", "sel_sensor", "online", "order_lta", 
         "downloader", "overwrite_safe", "rm_safe", "max_cloud_safe",
-        "step_atmcorr", "timewindow", "timeperiod", "extent", 
+        "step_atmcorr", "sen2cor_use_dem", "sen2cor_gipp", 
+        "timewindow", "timeperiod", "extent", 
         "s2tiles_selected", "s2orbits_selected", "list_prods", "list_indices", 
         "list_rgb",  "rgb_ranges", "index_source", "mask_type", "max_mask",
         "mask_smooth", "mask_buffer", "clip_on_extent", "extent_as_mask", 
