@@ -7,24 +7,25 @@ testthat::test_that(
     s2_list_test <- s2_list(
       tile = "32TNR",
       time_interval = as.Date(c("2017-05-01", "2017-05-31")),
-      orbit = "065",
-      output_type = "data.table"
+      orbit = "065"
     )
-    testthat::expect_is(s2_list_test, "data.table")
-    testthat::expect_equal(nrow(s2_list_test), 3)
-    testthat::expect_true(min(as.Date(s2_list_test$sensing_datetime)) >= as.Date("2017-05-01"))
-    testthat::expect_true(max(as.Date(s2_list_test$sensing_datetime)) <= as.Date("2017-08-01"))
-    testthat::expect_equal(unique(s2_list_test$id_tile), "32TNR")
-    testthat::expect_equal(unique(s2_list_test$id_orbit), "065")
-    testthat::expect_equal(mean(s2_list_test$clouds), 38.3432, tolerance = 1e-6)
-    testthat::expect_equal(unique(s2_list_test$online), NA)
+    testthat::expect_is(s2_list_test, "safelist")
+    s2_dt_test <- as(s2_list_test, "data.table")
+    testthat::expect_is(s2_dt_test, "data.table")
+    testthat::expect_equal(nrow(s2_dt_test), 3)
+    testthat::expect_true(min(as.Date(s2_dt_test$sensing_datetime)) >= as.Date("2017-05-01"))
+    testthat::expect_true(max(as.Date(s2_dt_test$sensing_datetime)) <= as.Date("2017-08-01"))
+    testthat::expect_equal(unique(s2_dt_test$id_tile), "32TNR")
+    testthat::expect_equal(unique(s2_dt_test$id_orbit), "065")
+    testthat::expect_equal(mean(s2_dt_test$clouds), 38.3432, tolerance = 1e-6)
+    testthat::expect_equal(unique(s2_dt_test$online), NA)
     testthat::expect_equal(
-      grepl("^https://scihub\\.copernicus\\.eu",s2_list_test$url),
+      grepl("^https://scihub\\.copernicus\\.eu",s2_dt_test$url),
       rep(TRUE, 3)
     )
     
     # test safe_getMetadata
-    safe_metadata <- safe_getMetadata(s2_list_test[order(sensing_datetime),]$name, info = "nameinfo") # data.table
+    safe_metadata <- safe_getMetadata(s2_dt_test[order(sensing_datetime),]$name, info = "nameinfo") # data.table
     testthat::expect_is(safe_metadata, "data.table")
     testthat::expect_equal(unique(safe_metadata$prod_type), "product")
     testthat::expect_equal(unique(safe_metadata$version), "compact")
@@ -41,22 +42,24 @@ testthat::test_that(
     s2_list_test <- s2_list(
       tile = "32TNR",
       time_interval = as.Date(c("2017-05-01", "2017-05-31")),
-      output_type = "vector",
       availability = "check"
     )
     testthat::expect_is(s2_list_test, "safelist")
-    testthat::expect_equal(length(s2_list_test), 6)
+    s2_sf_test <- as(s2_list_test, "sf")
+    testthat::expect_is(s2_sf_test, "sf")
+    testthat::expect_equal(sf::st_crs(s2_sf_test)$epsg, 4326)
+    testthat::expect_equal(nrow(s2_sf_test), 6)
     testthat::expect_is(
-      safe_getMetadata(names(s2_list_test), info = "nameinfo", format = "list"), 
+      safe_getMetadata(names(s2_sf_test$name), info = "nameinfo", format = "list"), 
       "list"
     )
 
-    testthat::expect_true(min(as.Date(attr(s2_list_test, "sensing_datetime"))) >= as.Date("2017-05-01"))
-    testthat::expect_true(min(as.Date(attr(s2_list_test, "sensing_datetime"))) <= as.Date("2017-05-31"))
-    testthat::expect_equal(unique(attr(s2_list_test, "id_tile")), "32TNR")
-    testthat::expect_true(all(attr(s2_list_test, "id_orbit") %in% c("022","065")))
-    testthat::expect_equal(mean(attr(s2_list_test, "clouds")), 58.36295, tolerance = 1e-6)
-    testthat::expect_true(all(attr(s2_list_test, "online") %in% c(TRUE, FALSE)))
+    testthat::expect_true(min(as.Date(s2_sf_test$sensing_datetime)) >= as.Date("2017-05-01"))
+    testthat::expect_true(min(as.Date(s2_sf_test$sensing_datetime)) <= as.Date("2017-05-31"))
+    testthat::expect_equal(unique(s2_sf_test$id_tile), "32TNR")
+    testthat::expect_true(all(s2_sf_test$id_orbit %in% c("022","065")))
+    testthat::expect_equal(mean(s2_sf_test$clouds), 58.36295, tolerance = 1e-6)
+    testthat::expect_true(all(s2_sf_test$online %in% c(TRUE, FALSE)))
   }
 )
 
@@ -153,21 +156,19 @@ testthat::test_that(
   "Tests on s2_list - multipoint", {
     pp <- data.frame(x = c(6, 9.95),
                      y = c(45.81, 45.95))
-    pos <- sf::st_as_sf(pp, coords = c("x","y")) %>% sf::st_set_crs(4326)
+    pos <- sf::st_set_crs(sf::st_as_sf(pp, coords = c("x","y")), 4326)
     time_window <- as.Date(c("2016-05-01", "2016-05-31"))
-    s2_list_test <- s2_list(
-      spatial_extent = pos,
-      time_interval = time_window,
-      output_type = "data.table"
+    s2_list_test <- as(
+      s2_list(spatial_extent = pos, time_interval = time_window), 
+      "data.frame"
     )
     testthat::expect_equal(length(s2_list_test$id_orbit), 12)
     
     # reproject
     pos <- sf::st_transform(pos, 32632)
-    s2_list_test <- s2_list(
-      spatial_extent = pos,
-      time_interval = time_window,
-      output_type = "data.table"
+    s2_list_test <- as(
+      s2_list(spatial_extent = pos, time_interval = time_window),
+      "data.frame"
     )
     testthat::expect_equal(length(s2_list_test$id_orbit), 12)
   }
@@ -267,14 +268,14 @@ testthat::test_that(
 testthat::test_that(
   "Tests on s2_list - process level", {
     pos <- sf::st_sfc(sf::st_point(c(9.85,45.81)), crs = 4326)
-    s2_list_test <- s2_list(
+    s2_list_test <- as.data.table(s2_list(
       spatial_extent = pos,
       tile = "32TNR",
       level = "auto",
       time_interval = as.Date(c("2016-05-01", "2017-06-30")),
       time_period = "seasonal",
-      orbit = "065", output_type = "data.table"
-    )
+      orbit = "065"
+    ))
     testthat::expect_equal(length(s2_list_test$level), 11)
     testthat::expect_equal(unique(s2_list_test$level), c("1C" , "2Ap"))
     # test safe_getMetadata
@@ -283,14 +284,14 @@ testthat::test_that(
     testthat::expect_equal(dim(safe_metadata), c(11,11))
     testthat::expect_equal(unique(safe_metadata$level), c("1C","2A"))
     
-    s2_list_test <- s2_list(
+    s2_list_test <- as.data.table(s2_list(
       spatial_extent = pos,
       tile = "32TNR",
       level = "L1C",
       time_interval = as.Date(c("2016-05-01", "2017-06-30")),
       time_period = "seasonal",
-      orbit = "065", output_type = "data.table"
-    )
+      orbit = "065"
+    ))
     testthat::expect_equal(length(s2_list_test$level), 11)
     testthat::expect_equal(unique(s2_list_test$level), c("1C"))
     # test safe_getMetadata
@@ -311,7 +312,10 @@ testthat::test_that(
         spatial_extent = "pos",
         time_interval = as.Date(c("2017-05-01", "2017-06-30"))
       ),
-      regexp = "`spatial_extent` is not a `sf` or `sfc` object"
+      regexp = gsub(
+        " ", "[ \n]",
+        "`spatial_extent` is not a `sf` or `sfc` object"
+      )
     )
     
     # wrong dates
@@ -320,7 +324,10 @@ testthat::test_that(
         spatial_extent = pos,
         time_interval = c("2017-05-XX", "2017-06-30")
       ),
-      regexp = "`time_interval` must be of class .+ cohercible to Date"
+      regexp = gsub(
+        " ", "[ \n]",
+        "`time_interval` must be of class .+ cohercible to Date"
+      )
     )
     
     # wrong availability
@@ -330,7 +337,10 @@ testthat::test_that(
         time_interval = c("2017-05-01", "2017-06-30"),
         availability = "offline"
       ),
-      regexp = '`availability` must be one among "online", "lta", "check" and "ignore"'
+      regexp = gsub(
+        " ", "[ \n]",
+        '`availability` must be one among "online", "lta", "check" and "ignore"'
+      )
     )
   }
 )
